Release Notes
=============

v0.2.0
------

- Added ``rechunker.executors`` for executing plans with other
  backends like Apache Beam, prefect, and pywren. See :ref:`executors` for more.
- Fixed overflow bug when computing the number of chunks needed for a memory target.

v0.0.1
-----------------

- Documentation update and tutorial.
- Allow rechunk to accept a Dask array.


v0.0.1 - 2020-07-15
-------------------

First Release
